==> hyperscan_4.2.0.orig.tar.gz: hyperscan-4.2.0/src/util/dump_charclass.h <==
/*
 * Copyright (c) 2015-2016, Intel Corporation
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *  * Neither the name of Intel Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

/** \file
 * \brief Dump code for character classes (expressed as CharReach objects).
 */

#ifndef DUMP_CHARCLASS_H
#define DUMP_CHARCLASS_H

#include "ue2common.h"

#include <cstdio>
#include <ostream>
#include <string>

namespace ue2 {

enum cc_output_t {
    CC_OUT_TEXT, //!< unescaped text output
    CC_OUT_DOT   //!< escaped DOT label output
};

class CharReach;

void describeClass(std::ostream &os, const CharReach &cr, size_t maxLength = 16,
                   enum cc_output_t out_type  = CC_OUT_TEXT);

std::string describeClass(const CharReach &cr, size_t maxLength = 16,
                          enum cc_output_t out_type = CC_OUT_TEXT);

void describeClass(FILE *f, const CharReach &cr, size_t maxLength,
                   enum cc_output_t out_type);

} // namespace ue2

#endif // DUMP_CHARCLASS_H

==> hyperscan_4.4.0.orig.tar.gz: hyperscan-4.4.0/src/util/dump_charclass.h <==
/*
 * Copyright (c) 2015-2016, Intel Corporation
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *  * Neither the name of Intel Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

/** \file
 * \brief Dump code for character classes (expressed as CharReach objects).
 */

#ifndef DUMP_CHARCLASS_H
#define DUMP_CHARCLASS_H

#include "ue2common.h"

#include <cstdio>
#include <ostream>
#include <string>
#include <vector>

namespace ue2 {

enum cc_output_t {
    CC_OUT_TEXT, //!< unescaped text output
    CC_OUT_DOT   //!< escaped DOT label output
};

class CharReach;

void describeClass(std::ostream &os, const CharReach &cr, size_t maxLength = 16,
                   enum cc_output_t out_type  = CC_OUT_TEXT);

std::string describeClass(const CharReach &cr, size_t maxLength = 16,
                          enum cc_output_t out_type = CC_OUT_TEXT);

std::string describeClasses(const std::vector<CharReach> &v,
                            size_t maxClassLength = 16,
                            enum cc_output_t out_type = CC_OUT_TEXT);

void describeClass(FILE *f, const CharReach &cr, size_t maxLength,
                   enum cc_output_t out_type);

} // namespace ue2

#endif // DUMP_CHARCLASS_H
